function this=homer_config()
% Create the Homer configuration object.
%
%   >> this=homer_config
%
% Type >> homer_config  to see the list of current configuration option values.

% $Revision: 1873 $ ($Date: 2012-07-10 10:21:26 +0100 (Tue, 10 Jul 2012) $)
%
%--------------------------------------------------------------------------------------------------
%  ***  Alter only the contents of the subfunction at the bottom of this file called     ***
%  ***  default_config, and the help section above, which describes the contents of the  ***
%  ***  configuration structure.                                                         ***
%--------------------------------------------------------------------------------------------------
% This block contains generic code. Do not alter. Alter only the sub-function default_config below

config_name=mfilename('class');
build_configuration(config,@homer_defaults,config_name);
this=class(struct([]),config_name,config);


%--------------------------------------------------------------------------------------------------
%  Alter only the contents of the following subfunction, and the help section of the main function
%
%  This subfunction sets the field names, their defaults, and which ones are sealed against change
%  by the 'set' method.
%
%  The sealed fields must be a cell array of field names, or can be empty. The matlab function
%  struct that can be used has confusing syntax for this purpose: suppose we have fields
%  called 'v1', 'v2', 'v3',...  then we might have:
%   - if no sealed fields:  ...,sealed_fields,{{''}},...
%   - if one sealed field   ...,sealed_fields,{{'v1'}},...
%   - if two sealed fields  ...,sealed_fields,{{'v1','v2'}},...
%
%--------------------------------------------------------------------------------------------------
function defaults=homer_defaults()

defaults = ...
    struct('instrument_name','',        ...   % instrumnent name
    'instr_config_folder','',    ...   % the text file with the instrument's configurations
    'instruments_root_dir','',   ...   % the folder where instrument files reside
    'user_output','',            ...   % the folder where user wants to write his result files; this folder has to be write-enabled;
    'instruments_allowed','',    ...   % field for instruments libisis understands;
    'use_hdf',0,                 ...   % if user should use hdf-format while writing spe files. 0 --  no, 1-- yes, 2 -- write both;
    'spe_hdf_version',1          ...   % version of spe-hdf file
    ) ;

% the instruments LIBISIS understands
defaults.instruments_allowed={'het','let','maps','mari','merlin'};

% and the location of the default configuration file
%defaults.instr_config_file       = ''; % undefined in constructor but will be defined after set(instrument_name

defaults.user_output=pwd;
defaults.sealed_fields={'sealed_fields',...
    'instr_config_folder',...
    'instruments_allowed',...
    'spe_hdf_version'}; % specify the fields which values can not be changed by user;

% Verify if the default instrument directory variable exisits (it would
% if you are in Libisis) and if not  set it to the folder
% under the directory where the Homer_ver0 has been called from (this will be
% the stand-alone default location
if isdeployed
    % HACK: 
    %compilation_path    = 'users/wkc26243/Documents/work/Libisis';
    %instr_files_location=fullfile(ctfroot,compilation_path,'InstrumentFiles');
    instr_files_location=fullfile(pwd,'InstrumentFiles');
else
    rootpath = fileparts(which('libisis_init'));
    instr_files_location = parse_path([rootpath '/../InstrumentFiles/']);
    if ~exist(instr_files_location,'dir') % stand-alone?
        instr_files_location=fullfile(pwd,'InstrumentFiles');
    end
end
defaults.instruments_root_dir=instr_files_location;
