function [argout,filled_out,d_int_requested]=homer_energy_transfer_int_rebin_set(arg,filled)
% Construct rebin arguments for monochromatic runs
%
% Specialised utility routine that assumes checking has already been performed:
% - that one and onoly one if ei and fixei has been filled, and with a numeric value greater than zero
% - that one and only one of d_int and d_rebin has been filled
% - that output units are energy transfer

argout=arg;
filled_out=filled;

if filled.ei
    ei=arg.ei;
else
    ei=arg.fixei;
end

if filled.d_rebin
    % Check that the values are OK
    argout.d_rebin=arg.d_rebin(:)';    % ensure row
    if ~(numel(argout.d_rebin)>=3 && mod(numel(argout.d_rebin),2)==1 && all(diff(argout.d_rebin)>0) && argout.d_rebin(end)<ei) &&...
       ~(numel(arg.d_rebin)==2 && arg.d_rebin(2)-arg.d_rebin(1)>0 && arg.d_rebin(2)<ei)
        error('Check value of d_rebin')
    end
    d_int_requested=false;
    
elseif filled.d_int
    % Check values are OK
    if ~(numel(arg.d_int)==2 && arg.d_int(2)-arg.d_int(1)>0 && arg.d_int(2)<ei)
        error('Check value of d_int')
    end
    % If we want to apply 'corr' on the data before integrating, then must populate with energy bins
    % (could use intrinsic bins of the data i.e. d_rebin=d_int, but could lead to large intermediate files)
    if filled.corr
        argout.d_rebin=[arg.d_int(1),ei/200,arg.d_int(2)];
        argout.d_int=[];
        filled_out.d_rebin=true;
        filled_out.d_int=false;
    end
    d_int_requested=true;
        
else
    % Assume rebinning required, and choose a default set rather than intrinsic binning:
    argout.d_rebin=[-ei/2.0, ei/200.0, 0.95*ei];
    filled_out.d_rebin=true;
    d_int_requested=false;
    
end
