function [dso,map_created]=map_prep(dso,map_file,map_type,arg)
% Add a map file into the data souce object. 
%
%   >> [dso,map_created]=map_prep(dso,map_file,map_type,arg)
%
%   map_file    default name of map file e.g. 'monmap.nxs' if one needs to be created
%   map_type    datatype in dso e.g. 'monmapfile'
%   arg         argument giving map information. One of:
%                 - name of an existing map file - in which case map_file is ignored
%                 - IXTmap object
%                 - argument from which the map file will be constructed 


% Find out if there is a map file in the dso
[path,found]=findpath(dso,map_type);

% Add/replace the map file
if ischar(arg) && size(arg,1)==1
    % Put the map file in the dso
    if(found)
        disp('INFO: map file entry in IXTdata_source object being over-ridden by supplied parameters')
        dso=replace_item(dso,arg,map_type);
    else
        dso=add_item(dso,arg,map_type);
    end
    map_created=false;
    
else
    if ~isa(arg,'IXTmap')
        arg=IXTmap(arg);    % attempt to make an IXTmap object from the input
    end
    % Create a nexus file on the fly
    fio=open(IXTfileio,map_file,4);
    write(arg,fio,'map');
    fio=close(fio);
    if(found)
        disp('INFO: map file entry in IXTdata_source object being over-ridden by supplied parameters')
        dso=replace_item(dso,map_file,map_type);
    else
        dso=add_item(dso,map_file,map_type);
    end
    map_created=true;
    
end
