function [dso,mask_created]=mask_prep(dso,mask_file,mask_type,arg)
% Add a mask file into the data souce object. 
%
%   >> [dso,mask_created]=mask_prep(dso,mask_file,mask_type,arg)
%
%   mask_file    default name of mask file e.g. 'monmask.nxs' if one needs to be created
%   mask_type    datatype in dso e.g. 'monmaskfile
%   arg          argument giving mask information. One of:
%                 - name of an existing mask file - in which case mask_file is ignored
%                 - IXTmask object
%                 - argument from which the mask file will be constructed 


% Find out if there is a mask file in the dso
[path,found]=findpath(dso,mask_type);

% Add/replace the mask file
if ischar(arg) && size(arg,1)==1
    % Put the mask file in the dso
    if(found)
        disp('INFO: mask file entry in IXTdata_source object being over-ridden by supplied parameters')
        dso=replace_item(dso,arg,mask_type);
    else
        dso=add_item(dso,arg,mask_type);
    end
    mask_created=false;
    
else
    if ~isa(arg,'IXTmask')
        arg=IXTmask(arg);    % attempt to make an IXTmask object from the input
    end
    % Create a nexus file on the fly in the working directory
    fio=open(IXTfileio,mask_file,4);
    write(arg,fio,'mask');
    fio=close(fio);
    if(found)
        disp('INFO: mask file entry in IXTdata_source object being over-ridden by supplied parameters')
        dso=replace_item(dso,mask_file,mask_type);
    else
        dso=add_item(dso,mask_file,mask_type);
    end
    mask_created=true;
    
end
