function setup_instrument_data_sources(data_dir,map_dir,nex_dir,mask_dir,inst_abrv_name)
% Set paths to instrument file locations and give instrument name
%
%   >> outdat=setup_instrument_dataFolders(data_dir,map_dir,nex_dir,mask_dir,inst)
%
%    Input: data_dir       location of input raw data files and output spe files
%           map_dir        location of map files (including monitor map files)
%           nex_dir        location of input NeXus instrument parameter files
%           mask_dir       location of mask files
%           inst_abrv_name abbreviated instrument name (e.g. 'map', 'mer')
%
% Note:
%   Homer does not know how to set spe output path output independent of input datadir


% Clear previous data_source information:
ixf_global_var('data_source','remove');
ixf_global_var('homer','remove');



% Set new global paths
delgpath('inst_data')
if iscellstr(data_dir)
    mkgpath('inst_data',data_dir{:});
else
    mkgpath('inst_data',data_dir);
end
delgpath('inst_nxs')
if iscellstr(nex_dir)
    mkgpath('inst_nxs',nex_dir{:});
else
    mkgpath('inst_nxs',nex_dir);
end
delgpath('inst_masks')
if iscellstr(mask_dir)
    mkgpath('inst_masks',mask_dir{:});
else
    mkgpath('inst_masks',mask_dir);
end

delgpath('inst_maps')
if iscellstr(map_dir)
    mkgpath('inst_maps',map_dir{:});
else
    mkgpath('inst_maps',map_dir);
end

% Set new data_source information
ixf_global_var('data_source','set','inst',inst_abrv_name);
ixf_global_var('data_source','set','ext','RAW');
ixf_global_var('data_source','set','path','inst_data:::');
ixf_global_var('data_source','set','sav_prefix','s');
