function indat=setup_instrument_dataFolders(varargin)
% Set paths to instrument file locations and give instrument name
%
%   >> indat=setup_instrument_dataFolders(data_dir,map_dir,nex_dir,mask_dir,inst)
%   >> indat=setup_instrument_dataFolders(data_dir,spe_dir,map_dir,nex_dir,mask_dir,inst)
%   >> indat=setup_instrument_dataFolders(input_data_structure) (form homer GUI)
%
% Input:
% -------
%   data_dir       location of input raw data files and output spe files
%   spe_dir        location for output spe files
%   map_dir        location of map files (including monitor map files)
%   nex_dir        location of input NeXus instrument parameter files
%   mask_dir       location of mask files
%   inst_abrv_name abbreviated instrument name (e.g. 'map', 'mer')
%
% Output:
% --------
%   indat          the structure which is used by the homer GUI to identify files location 
%                  plus internal variables set to the corresponding paths
%
% 
% $Revision: 1667 $ ($Date: 2010-04-29 19:10:04 +0100 (Thu, 29 Apr 2010) $)
%
% reduce all possible call choises to a single one
if nargin == 1
    indat=varargin{1};
    data_dir     = indat.datadir;
    spe_dir      = indat.spedir; 
    mask_dir     = indat.maskdir;
    map_dir      = indat.mapdir;
    nex_dir      = indat.paramdir;
    inst_abrv_name=indat.inst;
elseif nargin == 5
    data_dir  = varargin{1}; %data_dir
    spe_dir   = data_dir  ;
    map_dir   = varargin{2}; % map_dir
    nex_dir   = varargin{3}; % nex_dir
    mask_dir  = varargin{4}; % mask_dir
    inst_abrv_name= varargin{5};  
elseif nargin == 6
    data_dir  = varargin{1}; %data_dir
    spe_dir   = varargin{2}; 
    map_dir   = varargin{3}; % map_dir
    nex_dir   = varargin{4}; % nex_dir
    mask_dir  = varargin{5}; % mask_dir
    inst_abrv_name= varargin{6};  
else
    error(' setup_instrument_dataFolders has been called with wrong number of arguments');
end


if iscellstr(spe_dir)  % spe dir can be only one?
	spe_dir=spe_dir{1};
end
if ~exist(spe_dir,'dir')
	spe_dir=data_dir;
end
indat.inst      = inst_abrv_name;


%CLEAR previous data_source information
ixf_global_var('data_source','remove');
ixf_global_var('homer','remove');
% *** > added on 08/03/2010 to eliminate misterious reappearence of
% setup_XXX_diag_defaulds (setup_het_diag_defaults) while selecting another instrument. 
ixf_global_var('diag','remove');


delgpath('inst_maps')
delgpath('inst_nxs')
delgpath('inst_data')
delgpath('inst_results')
delgpath('inst_masks')

indat.datadir  =  check_data_folder(data_dir,'inst_data',inst_abrv_name);  %data_dir
indat.spedir   =  check_data_folder(spe_dir,'inst_results',inst_abrv_name);   % new and does not exist (have not been checked)
indat.paramdir = check_data_folder(nex_dir,'inst_nxs',inst_abrv_name);
indat.maskdir = check_data_folder(mask_dir,'inst_masks',inst_abrv_name);
indat.mapdir  = check_data_folder(map_dir,'inst_maps',inst_abrv_name);


% set new data_source information
ixf_global_var('data_source','set','inst',inst_abrv_name);
ixf_global_var('data_source','set','ext','RAW');
ixf_global_var('data_source','set','path','inst_data:::');
ixf_global_var('data_source','set','sav_prefix','s');




function outData=check_data_folder(inData,data_tag,instrumentName)
% This is internal service function for Homer. 
%
% The function adds the datapath specified as input argument to the libisis search path 
%
% In addition to that the function checks if the data folder 'inData' when inData is a single argument
% or first exisitig inData if inData is a cell array of path-es 
% any of it does not exist, fills in the result with defaulds, obtained from the
% instrument name and global variable, which describes the location of the
% instrument files;
% 
% 
% $Revision: 1667 $ ($Date: 2010-04-29 19:10:04 +0100 (Thu, 29 Apr 2010) $)
%
if iscellstr(inData)
	for i=1:length(inData)
		outData = inData{i};	
		if exist(outData,'dir')
			break;
		end
	end
else
    outData = inData;
end

if ~existgpath(data_tag)
    mkgpath(data_tag,inData);
else
    addbeggpath(data_tag,inData);
end

if(exist(outData,'dir'))
    return;
end
instrument_files=ixf_global_var('instrument_files','get','files_location');
if(isempty(instrument_files))
    outData = pwd;
    return;
end

outData=[instrument_files,filesep,instrumentName];
if(~exist(outData,'dir'))
    outData = pwd;    
end
