function rf=mon (dso,varargin)
% Populate an IXTrunfile object with monitor data only
%
%   >> runfile = mon(dso,run)
%   >> runfile = mon(dso,run,'keyword_1',arg1,'keyword_2',arg2,...)
%
% Optional keywords are:
%   'period'    Period number
%   'mon_map'   map file, IXTmap object or , for a single workspace, an
%              array of spectrum numbers
%   'mon_mask'  Mask file, IXTmask object, or an array of spectra to mask
%   'm_rebin'   Rebin parameters in the form:
%              [xlo,dx,xhi] or [x_1,dx_1,x_2,dx_2,...,x_n,dx_n,x_n+1]


% NOTE: T.G.Perring, Feb 2010: removed the line:
%       [present,argout] = getdefaults(present,argout);
% that immediately followed parse_argument command. This is too dangerous,
% as it will transfer relevant homer defaults e.g. background or mask files.

arglist = struct(... % argument names and default values
    'period',1,...
    'mon_map','',...
    'mon_mask','',...
    'm_rebin',[]);


% Parse arguments
[par,argout,present,filled] = parse_arguments(varargin,arglist);


% Fill output runfile object
% --------------------------------
rf=IXTrunfile;

% Add command that will reproduce the output
rf=create_population_command(rf,inputname(1),mfilename('fullpath'),mfilename,par,argout,filled);

% If there are run numbers or files defined in the par cell array, create entries in the dso
dso=create_dso_from_par(dso,par);

% If mask or map file(s) provided, add these to dso, over-riding any in the dso
monmap_created=false;
monmask_created=false;
monmap_tmpfile='temp_monmap.nxs';
monmask_tmpfile='temp_monmask.nxs';

if(filled.mon_map);
    [dso,monmap_created]=map_prep(dso,monmap_tmpfile,'monmapfile',argout.mon_map);
end
if(filled.mon_mask)    
    [dso,monmask_created]=mask_prep(dso,monmask_tmpfile,'monmaskfile',argout.mon_mask);
end

% Define the runfile as a diffraction instrument, because you may be
% able to do diffraction related units changes which don't require L2 or ei
dso=add_diffinst(dso);

% No normalisation performed, simply populates the mon_data object
rf=mon_pop(rf,dso,argout,filled);


% Delete temporary NeXus files
% ------------------------------
if(monmap_created)
    delete (monmap_tmpfile)
    dso=del_item(dso,'monmapfile');        
end
if(monmask_created)
    delete (monmask_tmpfile)
    dso=del_item(dso,'monmaskfile');        
end
