function dso_out=create_dso_from_par(dso_in,varargin)
% Fill the dso with the full paths to raw data source(s).
%
%   >> dso_out=create_dso_from_par(dso_in,par1,par2, ...)
%
% Arguments can be:
%  - run numbers or array of run numbers  e.g.  [1234,11560:11565]  or  11567
%  - string representation of run numbers e.g. '[1234,11560:11565]' or '1234, 456' or '11567'
%  - character strings or character arrays of files
%       e.g. 'map01234.raw'    ['map01234.raw';'map01336.raw']
%  - cell array of strings
%       e.g.  {'map01234.raw','1345','inst_data:::map11456.raw','c:\temp\let00111.raw'}
%
% If there are no raw data sources supplied in the input arguments then any that
% are in the dso will be used as the source of data.

dso_out=dso_in;
if numel(varargin)>=1 && ~isempty(varargin{1})
    % Input argumenet(s) supplied
    % Remove all rawfile references if they exist
    [rawpath,found]=findpath(dso_out,'rawfile');
    if(found)
        dso_out=del_item(dso_out,'rawfile');
        disp('INFO: rawfile entry in IXTdata_source object will be over-ridden by supplied parameters')
    end
    [rawpath,found]=findpaths(dso_out,'rawfile_mult');
    if(found)
        for j=size(rawpath,1)
            dso_out=del_item(dso_out,'rawfile_mult');
        end
        disp('INFO: multiple rawfile entry in IXTdata_source object will be over-ridden by supplied parameters')
    end
    % Create new path(s) from parameter input and add to dso
    rpath=make_path_from_par(varargin{:});
    if numel(rpath)>1
        for i=1:numel(rpath)
            dso_out=add_item(dso_out,rpath{i},'rawfile_mult');
        end
    else
        dso_out=add_item(dso_out,rpath{1},'rawfile');
    end
else
    % No data source arguments given; check that there is a source of data in the dso
    [rawpath,found]=findpath(dso_out,'rawfile');
    if(~found)
        [rawpath,found]=findpaths(dso_out,'rawfile_mult');
    end
    if(~found)
        error('No data file input present');
    end
end
