function fermi_chopper = IXTfermi_chopper(varargin)
% Constructor for IXTfermi_chopper object
%
%   >> fermi_chopper = IXTfermi_chopper (distance,frequency,radius,curvature,slit_width)
%   >> fermi_chopper = IXTfermi_chopper (distance,frequency,radius,curvature,slit_width,slit_spacing)
%
% For experts: full constructor:
%   >> fermi_chopper = IXTfermi_chopper ([IXTbase],name, 
%                                        distance,frequency,radius,curvature,slit_width,slit_spacing,
%                                        blade_width,width,height,energy);
%
%
%   IXTbase;        Information for use in NeXus or other files
%   name            Name of the slit package (e.g. 'sloppy')
%   distance        Distance from sample (m) (+ve if upstream of sample)
%   frequency       Frequency of rotation (hz)
%   period          Period of chopper rotation (s) = 1/frequency
%   radius          Radius of chopper body (m)
%   curvature       Radius of curvature of slits (m)
%   slit_width      Slit width (m)  (Fermi)
%   slit_spacing    Spacing between slit centres (m)
%   blade_width     Thickness of neutron absorbing slat
%   width           Width of aperture (m)
%   height          Height of aperture (m)
%   energy          Energy of neutrons transmitted by chopper (mev)

% Create a blank IXTfermi_chopper - this is needed as fortran cannot create real classes

fermi_chopper.base = IXTbase;       % Information for use in NeXus or other files
fermi_chopper.name = ' ';           % Name of the slit package (e.g. 'sloppy')
fermi_chopper.distance = 0;         % Distance from sample (m) (-ve if upstream of sample)
fermi_chopper.frequency = 0;        % Frequency of rotation (hz)
fermi_chopper.period = 0;           % Period of chopper rotation (s) = 1/frequency
fermi_chopper.radius = 0;           % Radius of chopper body (m)
fermi_chopper.curvature = 0;        % Radius of curvature of slits (m)
fermi_chopper.slit_width = 0;       % Slit width (m)  (Fermi)
fermi_chopper.slit_spacing = 0;     % Spacing between slit centres (m)
fermi_chopper.blade_width = 0;      % Thickness of neutron absorbing slat
fermi_chopper.width = 0;            % Width of aperture (m)
fermi_chopper.height = 0;           % Height of aperture (m)
fermi_chopper.energy= 0;            % Energy of neutrons transmitted by chopper (mev)
fermi_chopper = class(fermi_chopper,'IXTfermi_chopper');  


% Case of empty constructor, just return
if nargin==0, return, end

% Just make copy if single input that is an IXTfermi_chopper
if nargin==1 && isa(varargin{1},'IXTfermi_chopper')
    fermi_chopper=varargin{1};
    return
end

% Check for special constructor
if nargin==5||nargin==6
    args=[{IXTbase},{' '},varargin(1:2),{1/varargin{2}},varargin(3:end)];
    if nargin==5, args=[args,{0}]; end
    args=[args,{0},{0},{0},{0}];
    fermi_chopper = libisisexc('IXTfermi_chopper','create',fermi_chopper,args);
elseif nargin>0
    % Check if first argument class is IXTbase, and prepend if not
    if ~isa(varargin{1},'IXTbase'), varargin={IXTbase,varargin{:}}; end
    fermi_chopper = libisisexc('IXTfermi_chopper','create',fermi_chopper,varargin);
end
