function mask = IXTmask(varargin)
% Construct a libisis mask object
%
%   >> mask_object = IXTmask(spec_list)
%
% e.g.
%   >> my_mask = IXTmask([1:15,241:256])
%
% For experts: full constructor with IXTbase object:
%   >> mask_object = IXTmask(base,spec_list)

mask.base = IXTbase;
mask.mask_array = int32(1);
mask = class(mask,'IXTmask');

% Case of empty constructor, just return
if nargin==0, return, end

% Just make copy if single input that is an IXTmask
if nargin==1 && isa(varargin{1},'IXTmask')
    mask=varargin{1};
    return
end

% Check if first argument class is IXTbase, and prepend if not
if ~isa(varargin{1},'IXTbase'), varargin={IXTbase,varargin{:}}; end
if numel(varargin)~=2, error('Check number of input arguments'), end

if isnumeric(varargin{2})
    varargin{2}=int32(unique(varargin{2}(:)'));     % must be row vector
else
    error('List of spectra to be masked must be numeric')
end
mask = libisisexc('IXTmask','create',mask,varargin);
