function r = IXTraw_file(data_source)
% Create IXTraw_file object from run number or full file name. Only one file name is allowed.
%
%   >> raw_handle = IXTraw_file(run_number)
% *or*
%   >> raw_handle = IXTraw_file(filename)
%
%   run_number      Run number; the full file is built from the path, instrument
%                   and extension set with the set_path, set_inst, set_ext
%                   functions. These may already have been set by the default 
%                   instrument setup files.
%
%   filename        Full file name of data
%
% Examples: 
%   >> raw_handle = IXTraw_file(11012)
%   >> raw_handle = IXTraw_file('c:/maps_files/rawfiles/MAP11012.RAW')


r.runid = ' ';
r.found = false;
r.ntc1 = 0;
r.nsp1 = 0;
r.ndet = 0;
r.nper = 0;
r.nmon=0;
r.nuse=0;
r.daeh=[ 0 0 ];
r = class(r,'IXTraw_file');
if (nargin > 0)
    % *** > dirty hack -- some tests do not work without it
    % build default pathes based on the exisitng file name supplied
    if ischar(data_source)
        if exist(data_source,'file')
            build_par_from_file(data_source);
        end
    end
    % *** > dirty hack -- some tests do not work without it
    
    % Make full path    
    [rawfile_name,ok,mess]=make_path_from_par(data_source);
    if ~ok
        error(mess)
    elseif numel(rawfile_name)~=1
        error('Must give just one data source e.g. single run number, single file name')
    end
    r = libisisexc('IXTraw_file', 'create', r, translate_read(rawfile_name{1}));
    r = libisisexc('IXTraw_file', 'open', r);
end
%
function build_par_from_file(data_source)
def_path=ixf_global_var('data_source','get','path');
def_inst=ixf_global_var('data_source','get','inst');
def_ext=ixf_global_var('data_source','get','ext');
if isempty(def_path)||isempty(def_inst)||isempty(def_ext)
    [fpath,fname,fext]=fileparts(data_source);
    if isempty(def_path), ixf_global_var('data_source','set','path',fpath); end;
    if isempty(def_ext), ixf_global_var('data_source','set','ext',fext);    end;
    if isempty(def_ext)
         inst = upper(instrument_name(fname));
         ixf_global_var('data_source','set','inst',inst);                                
    end
end
