function r = getspectrum(self,spec_list,period)
% Function to read a spectrum or set of spectra into one or more dataset_1d.
%
%   >> dataset_1d = getspectrum (rawfile, spec_list)            % for first period
%   >> dataset_1d = getspectrum (rawfile, spec_list, period)    % for a given period number
% 
% Input:
% -------
%   rawfile         IXTraw_file object
%   spec_list       Single spectrum number
%               OR  Array of spectra in usual matlab syntax 
%                       e.g. [1,3,15,16]
%                       e.g. [13:23]
%
%   period          Period number [scalar; if an array, then first period number used]
%                   The spectrum numbers must be in the range of one period
%                  i.e. in the range 0 to nsp
%                   If period=0, then the spectrum numbers can lie in the full
%                  range of the raw file i.e. 0 to (nperiods*(nsp+1)-1), that is,
%                  (nsp+1) spectra per period, with the first numbered spectrum 0.
%
% Output:
% -------
%   dataset_1d      Single dataset_1d if single spectrum, or array of dataset_1d

if nargin < 2 || ~isnumeric(spec_list)
    error('Must give spectrum number(s)')
end

if nargin < 3
    period=1;   % *** changed from 0 by TGP, Jan 2010. Seems to be less dangerous
end

% Period cannot be array-valued, so takes first element however big it is
period=period(1);
r = libisisexc('IXTraw_file', 'getspectrum', self, int32(spec_list), int32(period), IXTdataset_1d);
