function r = sumspec(self,spec_list,xmin,xmax,period)
% Integrate a list of spectra and put integrals in an IXTdataset_1d object
%
%   >> wout = sumspec(rawfile,spec_list,xmin,xmax)          % for first period
%   >> wout = sumspec(rawfile,spec_list,xmin,xmax,period)   % for a given period number
%
%
% Input:
% -------
%   rawfile         IXTraw_file object
%   spec_list       Single spectrum number
%               OR  Array of spectra in usual matlab syntax 
%                       e.g. [1,3,15,16]
%                       e.g. [13:23]
%
%   xmin, xmax      Lower and upper integration limits (microseconds)
%
%   period          Period number [scalar; if an array, then first period number used]
%                   The spectrum numbers must be in the range of one period
%                  i.e. in the range 0 to nsp
%                   If period=0, then the spectrum numbers can lie in the full
%                  range of the raw file i.e. 0 to (nperiods*(nsp+1)-1), that is,
%                  (nsp+1) spectra per period, with the first numbered spectrum 0.
%
% Output:
% -------
%   dataset_1d      Single dataset_1d containing the integrals


if nargin < 2 || ~isnumeric(spec_list)
    error('Must give spectrum number(s)')
end

if nargin < 4
    error('Must give lower and upper integration ranges (microseconds)')
end

if xmin>xmax
    error('Must have upper integration limit bigger than lower limit')
end

if nargin < 5
    period=1;
end

% Period cannot be array-valued, so takes first element however big it is
period=period(1);   % *** TGP Feb 2010: have not checked if period can be a vector, just as in getspectra
r = libisisexc('IXTraw_file', 'sumspec', self, int32(spec_list), xmin, xmax, int32(period), IXTdataset_1d);
