function abs=monovan_abs(rf_v,varargin)
% Calculate absolute calibration scale factor. It is the integrated intensity that
% corresponds to the cross-section of one V atom in mbarn/steradian.
%
% It is assumed that the input runfile has been corrected with option 'corr' and
% the intensity normalised with ...'abs',1,'mass',<V sample mass>,'RMM',50.9415,...
%
% Further, the correction factor only applies to other data sets that have been corrected
% 'corr', and which have been normalised by the same 'norm' and 'scale' options

arglist = struct(... % argument names and default values
    'zero',true,...
    'tiny',1e-10,...
    'huge',1e10,...
    'out_lo',0.01,...
    'out_hi',100, ...
    'v_lo',0.8, ...
    'v_hi',1.2, ...
    'v_sig',3);
flags = {'zero'};

[par,argout] = parse_arguments(varargin,arglist,flags);

% Determine the 'best' integrated intensity from the integrals in the runfile
ave_integral=abs_calc(rf_v,argout.zero,argout.tiny,argout.huge,argout.out_lo,argout.out_hi,argout.v_lo,argout.v_hi,argout.v_sig);

% Get absolute calibration factor, assuming that input integrals have been normalised to scattering per V atom
ei=geteival(rf_v);          % Ei for the monochromatic run
sigma_inc=van_incoh(ei);    % incoherent cross-section for V atom
abs=ave_integral/sigma_inc;
disp('ave int#######')
disp(ave_integral)
% Display absolute normalisation to screen
out=sprintf('Absolute Units Correction = %0.5g\n',abs);
disp(out);
