function r = getspectrum(varargin)
% Function to read a spectrum or set of spectra into one or more dataset_1d.
%
%   >> dataset_1d = getspectrum (spec_list)             % for first period
%   >> dataset_1d = getspectrum (spec_list, period)     % for a given period number
% 
% Input:
% -------
%   spec_list       Single spectrum number
%               OR  Array of spectra in usual matlab syntax 
%                       e.g. [1,3,15,16]
%                       e.g. [13:23]
%
%   period          Period number [scalar; if an array, then first period number used]
%                   The spectrum numbers must be in the range of one period
%                  i.e. in the range 0 to nsp
%                   If period=0, then the spectrum numbers can lie in the full
%                  range of the raw file i.e. 0 to (nperiods*(nsp+1)-1), that is,
%                  (nsp+1) spectra per period, with the first numbered spectrum 0.
%
% Output:
% -------
%   dataset_1d      Single dataset_1d if single spectrum, or array of dataset_1d


% Mirror function to the IXTraw_file method getspectrum, but here takes the IXTraw_file object
% from the data_source
%
%  $Revision: 1633 $    ($Date: 2009-09-16 19:31:25 +0100 (Wed, 16 Sep 2009) $)

if nargin < 1
    error('Must give spectrum number(s)')
end


self = ixf_global_var('data_source','get','rawfile');
if isempty(self)
    error('No default RAW file currently assigned')
elseif ~isa(self,'IXTraw_file')
    error('Currently assigned raw file is not IXTraw_file object')
end

r=getspectrum(self,varargin{:});
