function head(varargin)
% Print header information to the screen for one or more runs
%
%   >> head
%   >> head(12344)
%   >> head([12344:12368])
%   >> head('c:\temp\map00113.raw')
%   >> head('inst_data:::map14223.raw')
%   >> head(arg1,arg2,...)
%
% Arguments can be:
%  - run numbers or array of run numbers  e.g.  [1234,11560:11565]  or  11567
%  - string representation of run numbers e.g. '[1234,11560:11565]' or '1234, 456' or '11567'
%  - character strings or character arrays of files
%       e.g. 'map01234.raw'    ['map01234.raw';'map01336.raw']
%  - cell array of strings
%       e.g.  {'map01234.raw','1345','inst_data:::map11456.raw','c:\temp\let00111.raw'}

if nargin==0
    rawfile=ixf_global_var('data_source','get','rawfile');
    if isempty(rawfile)
        disp('No currently assigned raw file')
        return
    end
    head(rawfile);
else
    rawpath=make_path_from_par(varargin{:});
    for i=1:numel(rawpath)
        rawfile=IXTraw_file(rawpath{i});
        head(rawfile);
        disp(' ')
    end
end


%libisisexc('IXTraw_file', 'head', rawfile);

% ------------------------------------------------
% This works in matlab also:
% hdr = gget(rf,'hdr');
% user= gget(rf,'user');
% titl= gget(rf,'titl');
% crpb= gget(rf,'crpb');
% line1 = ['Run ID : ' hdr(1:8) '        User: ' hdr(9:28) '  Inst: ' user(5,:)];
% line2 = ['Protons: ' hdr(73:80) ' uAhrs  Date: ' hdr(53:72) ' to ' deblank(crpb(17,:)) ' ' deblank(crpb(20,:))];
% disp(line1);
% disp(line2);
% disp(titl(1:80));