function r = sumspec(varargin)
% Integrate a list of spectra and put integrals in an IXTdataset_1d object
%
%   >> wout = sumspec(spec_list,xmin,xmax)          % for first period
%   >> wout = sumspec(spec_list,xmin,xmax,period)   % for a given period number
%
%
% Input:
% -------
%   spec_list       Single spectrum number
%               OR  Array of spectra in usual matlab syntax 
%                       e.g. [1,3,15,16]
%                       e.g. [13:23]
%
%   xmin, xmax      Lower and upper integration limits (microseconds)
%
%   period          Period number [scalar; if an array, then first period number used]
%                   The spectrum numbers must be in the range of one period
%                  i.e. in the range 0 to nsp
%                   If period=0, then the spectrum numbers can lie in the full
%                  range of the raw file i.e. 0 to (nperiods*(nsp+1)-1), that is,
%                  (nsp+1) spectra per period, with the first numbered spectrum 0.
%
% Output:
% -------
%   dataset_1d      Single dataset_1d containing the integrals


% Mirror function to the IXTraw_file method sumspec, but here takes the IXTraw_file object
% from the data_source
%
%  $Revision: 1577 $    ($Date: 2009-09-16 19:31:25 +0100 (Wed, 16 Sep 2009) $)

if nargin < 3
    error('Must give spectrum number(s), and lower and upper integration limits')
end


self = ixf_global_var('data_source','get','rawfile');
if isempty(self)
    error('No default RAW file currently assigned')
elseif ~isa(self,'IXTraw_file')
    error('Currently assigned raw file is not IXTraw_file object')
end

r=sumspec(self,varargin{:});
