
function ixf_keepcurr_cmd(oid,hdl,type)
%--------------------------------------------------------------------------
%Function Syntax: ixf_keepcurr_cmd(figure_oid,figure_hdl)
%Purpose: to store the current figure. it will not be used for new plots
%Input: figure oid and handle
%Output: none
%Example: ixf_keepcurr_cmd('hdl',1)
%--------------------------------------------------------------------------

%global structure
[IXG_ST_ERROR, IXG_ST_STDVALUES]=ixf_global_var('libisis_graphics','get','IXG_ST_ERROR','IXG_ST_STDVALUES');

%check my figure
res = ixf_check_graphicfigure('hdl',hdl);
if (res == IXG_ST_STDVALUES.false)
    ixf_display_error(IXG_ST_ERROR.no_figure); 
end

     keepHandle_ = findobj(hdl,'Label',IXG_ST_STDVALUES.keep_label,'Tag',IXG_ST_STDVALUES.keep_tag);
     currHandle_ = findobj(hdl,'Label',IXG_ST_STDVALUES.curr_label,'Tag',IXG_ST_STDVALUES.curr_tag);
switch type
    case 'keep'
%set values
    ixf_setapplicationdata('hdl',hdl,'keep',IXG_ST_STDVALUES.true);
    ixf_setlabel_hold('hdl',hdl,'flag','true');
    set(keepHandle_,'enable','off');
    set(currHandle_,'enable','on');
    case 'release'
    ixf_setapplicationdata('hdl',hdl,'keep',IXG_ST_STDVALUES.false);
    ixf_setlabel_hold('hdl',hdl,'flag','false');
    set(keepHandle_,'enable','on');
    set(currHandle_,'enable','off');
    case 'current'
        % in this case, we want to unlock the given handle, and lock
        % everything else. So our first step is to lock everything
        
        % get the name tag of the figure given
        [name tag] = ixf_get_nametag('hdl',hdl);
        
        % get all associated figure handles with that name tag
        figureHandles_ = ixf_checkforfigure(name, tag);
        
        if figureHandles_
            for i = 1:numel(figureHandles_)
                ixf_keepcurr_cmd('hdl',figureHandles_(i),'keep')
            end
        end
        
        ixf_keepcurr_cmd('hdl',hdl,'release')
        
        
end
