function [fig_out, axes_out, plot_out] = ui_overplot_1d(w,format,varargin)
% User interface for overplotting functions.
%
% >> [fig_out, axes_out, plot_out] = ui_overplot_1d(w,format,varargin)
%
% Inputs:
%--------
% 
%  w            dataset         Can be any dataset that can be plotted
%                               using the d commands
% format       'l','e', etc    Same as ui_plotfigure, defines the type of
%                               plot (line, errorbar etc.)
% varargin      various         Same as varargin input to d commands

% Dean Whittaker 2008

%global structures
[IXG_ST_ERROR, IXG_ST_STDVALUES] = ixf_global_var('libisis_graphics','get','IXG_ST_ERROR','IXG_ST_STDVALUES');

%chk args
if ( nargin < 1 )
    ixf_display_error(IXG_ST_ERROR.wrong_arg);
end
%check my figure
currflag = ixf_checkinit(IXG_ST_STDVALUES.currentfigure);

if (currflag == IXG_ST_STDVALUES.false)
    % if no window exists, then create one using the standard plot command.
   [fig_out, axes_out, plot_out]=  uib_plotgeneral(w,format,varargin{:});
    return 
end

% get a list of all open figures
[figure_handles, axes_handles] = get_all_handles(0);
isheld = false(size(axes_handles));
for i = 1:length(axes_handles)
    % set the state of the plot to be held (same as "hold on" but without
    % messages)
    state = get(axes_handles(i), 'NextPlot');
    set(axes_handles(i),'NextPlot','add');
    
    % keep track of plots which were held before this operation
    if strcmp(state, 'add')
        isheld(i) = true;
    end
    
end   

%call already prepared de utility
%[figureHandle_, axesHandle_, plotHandle_] = de(w,'counter',IXG_ST_STDVALUES.counter_increment,varargin{:});

switch format
    case 'e'
        [figureHandle_, axesHandle_, plotHandle_] = de(w,varargin{:},'keep_axis',true,'title','','xlabel','','ylabel','','counter',IXG_ST_STDVALUES.counter_increment);
    case 'l'
        [figureHandle_, axesHandle_, plotHandle_] = dl(w,varargin{:},'keep_axis',true,'title','','xlabel','','ylabel','','counter',IXG_ST_STDVALUES.counter_increment);
    case 'h'
            [figureHandle_, axesHandle_, plotHandle_] = dh(w,varargin{:},'keep_axis',true,'title','','xlabel','','ylabel','','counter',IXG_ST_STDVALUES.counter_increment);
    case 'p'
            [figureHandle_, axesHandle_, plotHandle_] = dp(w,varargin{:},'keep_axis',true,'title','','xlabel','','ylabel','','counter',IXG_ST_STDVALUES.counter_increment);
    case 'd'
          [figureHandle_, axesHandle_, plotHandle_] = dd(w,varargin{:},'keep_axis',true,'title','','xlabel','','ylabel','','counter',IXG_ST_STDVALUES.counter_increment);
    case 'm'
        [figureHandle_, axesHandle_, plotHandle_] = dm(w,varargin{:},'keep_axis',true,'title','','xlabel','','ylabel','','counter',IXG_ST_STDVALUES.counter_increment);
    otherwise
        error('Unknown Plot Type')
end

% some fields can be read but not set, we need to remove these.
% for k = 1:length(axes_handles)
% % This will tell us which fields can be set
% axis_allowed = set(axes_handles(k));
% 
% % list of all the fields we have properties for
% axis_fields = fields(axesprops{k});
% 
% % If we have a property that is not in the properties we can set, then
% % remove it. 
% for i = 1:length(axis_fields)
%     if ~isfield(axis_allowed,axis_fields{i})
%         axesprops{k} = rmfield(axesprops{k},axis_fields{i});
%     end
% end
% 
% % For some reason the 'children' field does not get removed 
% axesprops{k} = rmfield(axesprops{k},'Children');
% 
% % Reset the properties to their values before plotting
% set(axes_handles(k), axesprops{k});
% end

for i = 1:length(axes_handles)
    
    % only reset the state of the axes if it wasn't already held before
    if ~isheld(i)
        set(axes_handles(i),'NextPlot','replace');
    end

end   

    fig_out = figureHandle_;
    axes_out = axesHandle_;
    plot_out = plotHandle_;