function libisis_init(varargin)
% Adds the paths needed by Libisis.
%
% In your startup.m, add the libisis root path and call libisis_init, e.g.
%   addpath('c:\mprogs\libisis')
%   libisis_init
%
% Is PC and Unix compatible.

% T.G.Perring
%
% $Revision: 1853 $ ($Date: 2009-10-06 15:57:05 +0100 (Tue, 06 Oct 2009) $)

% Modified by RAE to initialise instrument files for only one instrument,
% rather than all of them. Also ensures that we clear the search path
% of any pre-exiting instrument search paths to avoid ambivalence in the
% event of multiple calls to startup.m

% root directory is assumed to be that in which this function resides
rootpath = fileparts(which('libisis_init'));
addpath(rootpath); % MUST have rootpath so that libisis_init, libisis_off included
addpath(fullfile(rootpath,'ISIS_utilities')); % this folder keeps generic 
                                              % utilites, which are needed to install and initiate all ISIS packages
% configurations folder; a libisisi configuration needed here;                                             
addpath(fullfile(rootpath,'applications','configurations')); 

%
addpath_message (2,rootpath,nargin);
%
gtk_init % in addition to paths, it sets up its internal variables

instr_name=get(homer_config,'instrument_name');
if isempty(instr_name)
     %instr_name=select_insrtument();
     instr_name=announce_instrument();
else
i_name=sprintf('%6s',instr_name);
disp( '!------------------------------------------------------------------!');
disp(['! your current instrument is :  ',upper(i_name),'                             !']);
disp( '!------------------------------------------------------------------!');
disp( '!   you can change you selected insrument by typing:               !');
disp( '!>> set(homer_config,''instrument_name'',instrument_name)            !');
disp( '!   where instrument_name can be: ''merlin'', ''maps'',''mari'' or ''het'' !');        
disp( '!------------------------------------------------------------------!');
end
% the command below sets both intsrument name and all subsequent data
% folders for homer.
% in theory it should not do this as the instrument parameters has to be
% present in config files, but as this is transitional version and not
% everything is in singleton, we need to issue this command
try
 % if Libisis was deleted from the computer but the configuration file has
 % been left, this would fail as system path has not been generated
 % to use new libisis propertly, we need to gen_system_path
set(homer_config,'instrument_name',instr_name);    
catch
   gen_System_path(rootpath); % plus modifies the version specific functions;    
   set(homer_config,'instrument_name',instr_name);    
   
end


%=====================

%=====================
%
% if (~strncmpi(computer,'PCWIN',5)) % temporary fix allowing to initiate old 
%                                     % libisis  binaries untill new libisis is ready
%     addpath('/usr/local/libisis/lib');
% end
[Matlab_code,Fortran_code] = libisis_version();
mc = [Matlab_code(1:48),'$)'];
fc = [Fortran_code(1:48),'$)'];
disp('!==================================================================!')
disp('!                    LIBISIS                                       !');
disp(['! Matlab  code: ',mc,' !']);
disp(['! FORTRAN code: ',fc,' !']);
disp('!==================================================================!')


%--------------------------------------------------------------------------
function addpath_message (type,varargin)
% Add a path from the component directory names, printing a message if the
% directory does not exist.
%
% T.G.Perring
%
gen_full_path=false;
if numel(varargin)>1
    string=fullfile(varargin{1},'');
    if varargin{2} >0
        gen_full_path=true;
    end
else
    string=fullfile(varargin{:},''); % '' is introduced for compartibility with
                                 % Matlab 7.7 and probably below which has
                                 % error in fullfile funtion
end                                 
if exist(string,'dir')==7
    if(type==1)
      path=genpath_(string); % generates path exclulind .svn and service folders beginning from "_"
      addpath(path);      
    else
     if get(libisis_config,'is_first_run') || (~strcmp(get(libisis_config,'last_used_matlab_version'),version())) || gen_full_path
         % similar to gentpath_, but copying the version specific dll-s to the path
         path=gen_System_path(string); % plus modifies the version specific functions;
         
        % set the version and the config controls not to call this
        % procedure again
        set(libisis_config,'is_first_run',0,'last_used_matlab_version',version());
     else
        path=genpath_special(string); % generates path exclulind .svn and service folders beginning from "_" (except system dll folder e.g. _R2009a)
     end
     addpath(path);     
    end
else
    warning('LIBISIS:libisis_init','"%s" is not a directory - not added to path',string)
end
