function libisis_init_user
% Adds the paths needed by Libisis.
%
% In your startup.m, add the libisis root path and call libisis_init, e.g.
%   addpath('c:\mprogs\libisis')
%   libisis_init
%
% Is PC and Unix compatible.

% T.G.Perring
%
% $Revision: 1633 $ ($Date: 2009-10-06 15:57:05 +0100 (Tue, 06 Oct 2009) $)

% Modified by RAE to initialise instrument files for only one instrument,
% rather than all of them. Also ensures that we clear the search path
% of any pre-exiting instrument search paths to avoid ambivalence in the
% event of multiple calls to startup.m

% root directory is assumed to be that in which this function resides
rootpath = fileparts(which('libisis_init'));
addpath(rootpath); % MUST have rootpath so that libisis_init, libisis_off included
addpath(fullfile(rootpath,'ISIS_utilities')); % this folder keeps generic 
                                              % utilites, which are needed to install and initiate all ISIS packages

%
addpath_message (2,rootpath);
%
gtk_init % in addition to paths, it sets up its internal variables

%============================
% refer to instrument files settings which should be the same level of
% directory as the current files. This is the first point where the user
% input is required. We first have to ensure that any other instruments on
% the search path are removed.

%Remove old settings (if any):
pdef=path;%long string containing the entire search path.
ind=strfind(pdef,'/merlin');
if ~isempty(ind)
    mypath=parse_path([rootpath '/../InstrumentFiles/' 'merlin' filesep]);
    rmpath(mypath);
    rmpath([mypath,'/homer']);
    rmpath([mypath,'/homer_gui']);
end
ind=strfind(pdef,'/maps');
if ~isempty(ind)
    mypath=parse_path([rootpath '/../InstrumentFiles/' 'maps' filesep]);
    rmpath(mypath);
    rmpath([mypath,'/homer']);
    rmpath([mypath,'/homer_gui']);
end
ind=strfind(pdef,'/mari');
if ~isempty(ind)
    mypath=parse_path([rootpath '/../InstrumentFiles/' 'mari' filesep]);
    rmpath(mypath);
    rmpath([mypath,'/homer']);
    rmpath([mypath,'/homer_gui']);
end
ind=strfind(pdef,'/het');
if ~isempty(ind)
    mypath=parse_path([rootpath '/../InstrumentFiles/' 'het' filesep]);
    rmpath(mypath);
    rmpath([mypath,'/homer']);
    rmpath([mypath,'/homer_gui']);
end



%Add new settings:
reply=input('Select which instrument you are using: MERlin MAPs HET MARi. Default is Merlin. ','s');
if isempty(reply)
    reply='MER';
end
reply=upper(reply);%ensure upper case

if strcmp(reply(1:3),'MER')
    instchoice='merlin';
elseif strcmp(reply(1:3),'MAP')
    instchoice='maps';
elseif    strcmp(reply(1:3),'MAR')
    instchoice='mari';
elseif    strcmp(reply(1:3),'HET')
    instchoice='het';
else
    instchoice='merlin';%default
end

disp('!------------------------------------------------------------------!');
disp(['      INSTRUMENT SELECTED IS: ',upper(instchoice),'               ']);
disp('!------------------------------------------------------------------!');


instrument_files = parse_path([rootpath '/../InstrumentFiles/' instchoice filesep]);

%=====================

% set the global variable which specifies the location of the instrument files
% this variable is used by homer_gui and is reset by the homer_gui when the gui is 
% compiled and run separately from Libisis. It it runs within Matlab and
% Libisis, the instrument files slould be as above

%Modified by RAE so that we tell Matlab where the root instrument files
%are:
% OBSOLETE:, moved to configuration
%inst_root=parse_path([rootpath '/../InstrumentFiles' filesep]);
%ixf_global_var('instrument_files','set','files_location',inst_root);

addpath_message (1,instrument_files); % and add path to the instrument settings

%=====================

%We now add an extra few lines of code (rather than modified lines) where
%we setup the instrument stuff for Homer.
if strcmp(reply(1:3),'MER')
    setup_merlin_data_sources;
elseif strcmp(reply(1:3),'MAP')
    setup_maps_data_sources;
elseif    strcmp(reply(1:3),'MAR')
    setup_mari_data_sources;
elseif    strcmp(reply(1:3),'HET')
    setup_het_data_sources;
else
    setup_merlin_data_sources;%default
end


%=====================
%
% if (~strncmpi(computer,'PCWIN',5)) % temporary fix allowing to initiate old 
%                                     % libisis  binaries untill new libisis is ready
%     addpath('/usr/local/libisis/lib');
% end
[Matlab_code,Fortran_code] = libisis_version();
mc = [Matlab_code(1:48),'$)'];
fc = [Fortran_code(1:48),'$)'];
disp('!==================================================================!')
disp('!                    LIBISIS                                       !');
disp(['! Matlab  code: ',mc,' !']);
disp(['! FORTRAN code: ',fc,' !']);
disp('!==================================================================!')


%--------------------------------------------------------------------------
function addpath_message (type,varargin)
% Add a path from the component directory names, printing a message if the
% directory does not exist.
%
% T.G.Perring
%

string=fullfile(varargin{:},''); % '' is introduced for compartibility with
                                 % Matlab 7.7 and probably below which has
                                 % error in fullfile funtion
if exist(string,'dir')==7
    if(type==1)
      path=genpath_special(string); % generates path exclulind .svn and service folders beginning from "_"
      addpath(path);      
    else
      path=gen_System_path(string); % as above, but copying the version specific dll-s to the path
      addpath(path);
    end
else
    warning('"%s" is not a directory - not added to path',string)
end
