function wout=section(w,varargin)
% Keep only the section of data in a given range. If histogram data,
% bins whose centres lie in the range are retained.
%
%   >> wout = section (win, xlo, xhi)
%   >> wout = section (win, [xlo, xhi])     % for notational consistency with higher dimensional objects

if numel(varargin)==1
    xlo=varargin{1}(1);
    xhi=varargin{1}(2);
elseif numel(varargin)==2
    xlo=varargin{1};
    xhi=varargin{2};
else
    error('Check number of input arguments')
end

wout=IXTdataset_1d;
if numel(w)>1, wout(numel(w))=wout; wout=reshape(wout,size(w)); end  % allocate array

for i=1:numel(w)
    if numel(w(i).x)==numel(w(i).signal)    % point mode
        x=w(i).x;
        itype=0;
    else
        x=0.5*(w(i).x(1:end-1)+w(i).x(2:end));
        itype=1;
    end
    ind=(x>=xlo & x<=xhi);
    i1=find(ind,1,'first');
    i2=find(ind,1,'last');
    if ~isempty(i1)
        x=w(i).x(i1:i2+itype); signal=w(i).signal(i1:i2); err=w(i).error(i1:i2);
    else
        error('No data in the requested range for one (or more, if array) of the dataset(s)')
    end
    wout(i)=IXTdataset_1d(IXTbase, w(i).title, signal, err, w(i).s_axis, x, w(i).x_axis, w(i).x_distribution);
end
