function wout = smooth_mslice(win,nsmooth)
% Smooth IXTdataset_2d using the mslice algorithm: repeated normalised convolution with a 3x3 matrix
%
%   >> wout = smooth(win,nsmooth)

if nargin<2
    error('Must give mslice smoothing value: 0(=no smoothing),1,2,...')
end

wout=win;
for i=1:numel(wout)
    ok=~isnan(wout(i).signal);
    [wout(i).signal,wout(i).error]=smooth_mslice_inner(wout(i).signal,wout(i).error,ok,nsmooth);
end

%=====================================================================================================
function [yout,eout]=smooth_mslice_inner(y,e,ok,nsmooth)
% Smooth data using the mslice algorithm: repeated normalised convolution with a 3x3 matrix
%
%   >> [yout,eout]=smooth_mlice(y,e,mask,nsmooth)
%
%   y,e,        2D arrays of intensity and variance (i.e. st. dev. squared)
%   ok          2D array of points to use (1=keep, 0=ignore)
%   nsmooth     How many times to repeat the smoothing
%
%   yout, eout  2D arrays of smoothed values
%
% Implemented just as in mslice

% T.G.Perring November 2009

c=[0.1 0.2 0.1; 0.2 0.8 0.2; 0.1 0.2 0.1];  % Convolution matrix

% Smooth data structure
% m=warning('off','MATLAB:divideByZero'); % turn off divide by zero messages, saving present state

yout=y;
eout=e;
weight = convn(double(ok),c,'same');    % weight function including only points where there is data
for i=1:nsmooth
    yout(~ok)=0;                        % Explicitly ensure y=e=0 for bins where ok=0
    eout(~ok)=0;
    yout = convn(yout,c,'same');        % points with no data (i.e. signal = 0) do not contribute to convolution
    yout(ok) = yout(ok)./weight(ok);
    eout = convn(eout,c.^2,'same');
    eout(ok) = eout(ok)./(weight(ok).^2);
end

% warning(m.state,'MATLAB:divideByZero'); % return to previous divide by zero message state

% Return 'bad' values to incoming values
yout(~ok) = y(~ok);
eout(~ok) = e(~ok);
