function gam=gamma(fermi,ei,phase)
% Calculate the reduced quantity gamma for a Fermi chopper (abs(gamma)<4 for transmission)
%
%   >> gam=gamma(fermi)           % pulse width for ei in Fermi chopper object
%   >> gam=gamma(fermi,ei)        % for an array of other ei
%   >> gam=gamma(fermi,ei,phase)
%
% Input:
% -------
%   fermi   IXTfermi_chopper object
%   ei      Incident energy (meV) (array or scalar)
%           If omitted or empty, use the ei value in the IXTfermi_chopper object
%   phase   if true, correctly phased; if false, 180 degrees out of phase
%           If omitted, then assume true
%
% Output:
% -------
%   gam     (2*R/peak_fwhh)*abs(1/s-1/v);   s=optimal transmission

c_e_to_t=2286.271456507406;         % t(us)=c_e_to_t *distance(m)/sqrt(E(meV))
if nargin<2
    vi=1e6*sqrt(fermi.energy)/c_e_to_t; % incident velocity (m/s)
else
    vi=1e6*sqrt(ei)/c_e_to_t;           % incident velocity (m/s)
end

omega=2*pi*fermi.frequency;
s=2*omega*fermi.curvature;
pk_fwhh=fermi.slit_width/(2*fermi.radius*omega);
if nargin<3 || phase
    gam=(2*fermi.radius/pk_fwhh)*abs(1/s-1./vi);
else
    gam=(2*fermi.radius/pk_fwhh)*abs(1/s+1./vi);
end
