function addendgpath(name,varargin)
% Add one or more directories to the end of a global path stored in the global path object
%
%   >> addendgpath(pathname,dir1,dir2,...)
%
% e.g. 
%   >> addendgpath('my_data_area','c:\rawfiles','d:\scratch\rawfiles')
%
% See also: mkgpath, delgpath, addgpath, rmgpath, addendgpath, addbeggpath, showgpath, existgpath


% Note: we check for unique occurences of directory names because the fortran code doesn't!
%
% Make sure this is synchronised with code in addbeggpath, which is identical apart from 
% the call to libisis that adds to beginning or end of path.

% Check global path name
if ~isvarname(name)
    error('Check global path is a character string')
end

if ~existgpath(name)
    error(['A global path with name ''',name,''' does not exist'])
end
    
% Check directory names are character strings
if isempty(varargin)
    return  % If didn't ask for anything to be added, so just return
end
for i=1:numel(varargin)
    [ok,dirs_add]=str_make_cellstr(varargin{:});
    if ~ok
        error('Check that directory names are character strings or cellarrays of character strings')
    end
end

% Add directories to path:
dirs=getgpath(name);
nadd=numel(dirs_add);
[dirs_cmn,dirs_add,dirs_current]=str_common(dirs_add,dirs,'first');
if numel(dirs_add)~=nadd
    display('Duplicate directory name(s) to be added to path. Taking first occurence(s)')
end
if numel(dirs_cmn)~=numel(dirs_current)
    % Not all directories currently exist in path, so remove any directories that are to be replaced
    if ~isempty(dirs_cmn)
        libisisexc('IXTpath','deldir_varargin',IXTpath,name,dirs_cmn);
    end
    % Now add directories to start of path
    r = libisisexc('IXTpath','addtoend_varargin',IXTpath,name,dirs_add);
    ixf_global_var('fortran','set','GPATH',r);
else
    % To avoid implicit deletion of global path, just delete outright and recreate
    libisisexc('IXTpath','delpath',IXTpath,name);
    r = libisisexc('IXTpath','addpath_varargin',IXTpath,name,varargin);
    ixf_global_var('fortran','set','GPATH',r);
end
