function ass(data_source)
% Assign a raw data file for data access by those functions which do not request
% the location of the data. The information about the data source is held in a
% global variable to make these functions easy to use and emulate old-style 
% mgenie commands.
%
%   >> ass(run_number)
% *or*
%   >> ass(filename)
%
%   run_number      Run number; the full file is built from the path, instrument
%                   and extension set with the set_path, set_inst, set_ext
%                   functions. These may already have been set by the default 
%                   instrument setup files.
%
%   filename        Full file name of data
%
% Examples: 
%   >> myraw = ass(11012)
%   >> ass('c:/maps_files/rawfiles/MAP11012.RAW')



% Make full path
[rawfile_name,ok,mess]=make_path_from_par(data_source);
if ~ok
    error(mess)
elseif numel(rawfile_name)~=1
    error('Must give just one data source e.g. single run number, single file name')
end

% Make IXTraw_file object, and save in data_source object
rawfile = IXTraw_file(rawfile_name{1});
ixf_global_var('data_source','set','rawfile', rawfile)
