function status=existgpath(name)
% Check if a particular global path is stored in the global path object:
%
%   >> status=existgpath            % check if any global paths exist
%   >> status=existgpath(pathname)  % check if named global path exists
%
%
% See also: mkgpath, delgpath, addgpath, rmgpath, addendgpath, addbeggpath, showgpath, existgpath

% *** Note: this routine does NOT interrogate the fortran - potential source of errors if set in fortran

if nargin==1 && ~isvarname(name)
    error('Check global path is a character string')
end

status=false;
if ixf_global_var('fortran','exist','GPATH')
    r=ixf_global_var('fortran','get','GPATH');
    if nargin==0
        if ~isempty(r)
            status=true;
        end
    else
        for i=1:numel(r)
            if strcmp(name,r(i).name)
                status=true;
                return
            end
        end
    end
end
