function outcell = getgpath(name)
% Get cell array of directories in named global path
%
%   >> namcell=getgpath         % cell array of all global paths
%   >> dircell=getgpath(name)   % cell array of directories in named path
%
% See also: mkgpath, delgpath, addgpath, rmgpath, addendgpath, addbeggpath, showgpath, existgpath

% *** Note: this routine does NOT interrogate the fortran - potential source of errors if set in fortran

if nargin==0
    if ~existgpath
        error('No global paths are defined')
    end
    r=ixf_global_var('fortran','get','GPATH');
    outcell=cell(numel(r),1);
    for i=1:numel(r)
        outcell{i}=r(i).name;
    end

else
    % Check global path name
    if ~isvarname(name)
        error('Check global path is a character string')
    end

    if ~existgpath(name)
        error(['A global path with name ',name,' does not exist'])
    end

    % Get the path
    r=ixf_global_var('fortran','get','GPATH');
    for i=1:numel(r)
        if strcmp(name,r(i).name)
            outcell=cellstr(r(i).directory);
        end
    end
end
