function [new_data_source,created]=make_data_sources_uppercase(data_source,ext)
% function lists all files with specified extension in the specified folder 
% and builds upper case symbolic links to these files. (unix only)
%
% usage:
% new_data_source=make_data_sources_uppercase(data_source,ext)
% where:
% data_source is the folder with files which has to be uppercase
% ext          -- the extension for these files
% output:
% new_data_source if the input folder data_source is open to writing, 
%                 the links are created ther and
%                 new_data_source=data_source
%                 otherwise new_data_source is a temporary folder in
%                 users directory
% created      -- the parameter which specifies if the links were created
%
% $Revision: 1846 $ ($Date: 2011-11-25 13:27:31 +0000 (Fri, 25 Nov 2011) $)
%
created = false;
list = dir(data_source);
isdir = logical(cat(1,list.isdir));
files = list(~isdir);

if ext(1)~='.'
    ext = ['.',ext];
end

fileNames  = cell(1,length(files));
files_2work= false(1,length(files));
ic = 0;
for i=1:length(files)
    [fpath,fname,fext]=fileparts(files(i).name);
    if strcmpi(ext,fext)
        ic = ic+1;
        fileNames{ic}=fname;
        files_2work(ic)=true;
    end
end
% no files with specified extension
if ~ic
    return;
end


% let's check if the data_source is open for writing and redefine it if it
% is not
tmpdir = 'tmp';
write_allowed = mkdir(fullfile(data_source,tmpdir));
if write_allowed
    new_data_source=data_source;
    rmdir(fullfile(data_source,tmpdir));
else
    new_data_source=fullfile(pwd,tmpdir);
    write_allowed = mkdir(new_data_source);    
    if ~write_allowed
        error('libisis:make_data_sources_uppercase',['both input folder ',data_source,' and output folder ',data_source,' are write protected']);
    end
end

fname = fileNames(files_2work);
for i=1:length(fname)
    make_upper_case_link(fullfile(data_source,upper([fname{i},ext])),new_data_source);
end
created =true;


