function done=make_upper_case_link(filename,varargin)
% The function intended to simulate case-independent (windows-like) file
% behavioud under UNIX
% it also places links intio new folder if one is specified in varargin{1}
%
% It analyses the name of the file supplied as the input argument 
% and if this file does not exist, but there is a file  with similar name
% but different case, it creates a symblic link to this file under unix
% Function does nothing under Windows
%
% usage:
% done=make_upper_case_link(filename,[new_folder])
%
% where:
% filename   -- name of the file. If such file does not exist and a 
%               different case file is present, the symbolic link with 
%               name filename will be created;
% new_folder -- if present, the location where to place new symbolic links,
%               if absent, links will be created alongside the found file
%
% returns  true if successfull or false if nothing is done
%
% $Revision: 1846 $ ($Date: 2011-11-25 13:27:31 +0000 (Fri, 25 Nov 2011) $)
%

done = false;
if strncmp(computer,'PCWIN',5)
    return
end
if nargin==1|| exist(filename,'file') % file already exist, nothing to do
    return
end

[path,name,ext]=fileparts(filename);

if ~isempty(varargin{:})
    new_path = varargin{1};         
    if ~exist(new_path,'dir')
        error('libisis:make_upper_case_link',' directory to put resulting links is requested but does not exist');
    end
else 
    new_path = path;
end
linkname = fullfile(new_path,[name,ext]);

there_is_file = fullfile(path,[name,lower(ext)]);
if exist(there_is_file,'file')
    done = make_link(linkname,there_is_file);
    return
end

there_is_file = fullfile(path,[lower(name),lower(ext)]);
if exist(there_is_file,'file')
    done =make_link(linkname,there_is_file);
    return
end

there_is_file = fullfile(path,[upper(name),lower(ext)]);
if exist(there_is_file,'file')
    done=make_link(linkname,there_is_file);
    return
end

there_is_file = fullfile(path,[upper(name),upper(ext)]);
if exist(there_is_file,'file')
    done=make_link(linkname,there_is_file);
    return
end

function done=make_link(link_name,full_file_name)
command =['ln ',full_file_name,' ',link_name];
done=unix(command);



