function mkgpath(name,varargin)
% Create a global path to be stored in the global path object:
%
%   >> mkgpath(pathname, dir1, dir2, ...)
%
%   pathname       Name to be given to global path
%   dir1, dir2,... Full directory names that will form the search path
%
% e.g. 
%   >> mkgpath('my_data_area','c:\rawfiles','d:\scratch\rawfiles')
%
% See also: mkgpath, delgpath, addgpath, rmgpath, addendgpath, addbeggpath, showgpath, existgpath

% Check global path name
if ~isvarname(name)
    error('Check global path is a character string')
end

if existgpath(name)
    error(['A global path with name ',name,' already exists'])
end
    
% Check directory names are character strings
if ~isempty(varargin)
    [ok,dirs]=str_make_cellstr(varargin{:});
    if ~ok
        error('Check that directory names are character strings or cellarrays of character strings')
    end
    dirs=strtrim(dirs);         % trim white space
    [dummy,ind]=unique(dirs,'first');
    if numel(ind)~=numel(dirs)
        display('Duplicate directory name(s) to be added to path. Taking first occurence(s)')
    end
    dirs=dirs(sort(ind));       % unique directories in order of first appearance
else
    error('Must give one or more directory names')
end

% Add global path to Fortran, and to Matlab
r = libisisexc('IXTpath','addpath_varargin',IXTpath,name,dirs);
ixf_global_var('fortran','set','GPATH',r);
