function this=load_hdf_data(this,file_name)
% the function loads spe data from proper spe_hfd file, identified by the
% file_name and with known hdf file extension
%
% if the file_name is not present, the filename is retrieved from the object
% itself;
%
% the file has to exist and have proper structure. Checks are done to
% verify this structure;
%
% $Revision: 1764 $ ($Date: 2011-02-18 22:06:38 +0000 (Fri, 18 Feb 2011) $)
%
fext = '.spe';
if(exist('file_name','var'))
    [filepath,filename,fext]=fileparts(file_name);
    this.filepath  =filepath;
    this.filename=filename;    
else
    filepath=this.filepath;
    filename=this.filename;
    if isempty(filename)
        error('SPE:load_hdf_Data',' file name to read data from is not defined in spe object');
    end
end
hext  = spe_hdf_filestructure('spe_hdf_file_ext');



% the name of prospective source of spe data with proper path and extension
ii=0;
for i=1:numel(hext)
    file_name = fullfile(filepath,[filename,hext{i}]);

    if(exist(file_name,'file'))
       fext = hext{i};
       ii    = i;
      break;
    end
end
if strcmpi(fext,'.spe')
    error('load_hdf_data:file_not_found',['can not found file: ',filename,' with any extension out of:  ',[hext{:}]]);
end
if strcmpi(fext,'.nxspe') % this is version 3; version 2 is spe_h5, but ii should be 2 as we are not looking through spe here
    root_nxspe_path  = find_root_nexus_dir(file_name,'NXSPE');
    data_field_names = spe_hdf_filestructure('data_field_names',ii);
    data_field_names = data_field_names{:};
    version_field = [root_nxspe_path,'/',data_field_names{5}];
    nxspe_file_description= hdf5read(file_name,version_field,'version'); 
    nxspe_version   = nxspe_file_description.Data;
    if strcmpi(nxspe_version ,'1.1')
        spe_hdf_file_version   = 3;
        spe_hdf_code_version = '3';
    else
        if strncmpi(nxspe_version ,'1',1)
            warning('load_hdf_data:file_not_supported',['nxspe file version ',nxspe_version,' found in file: ',filename,' does not have necessary fields and can be wrong'])
            spe_hdf_file_version   = 3;
            spe_hdf_code_version = '3';
        else
            error('load_hdf_data:file_not_supported',[' can not recognise nxspe file version ',nxspe_version,' found in file: ',filename]);
        end
    end
else
    data_field_names = spe_hdf_filestructure('data_field_names',ii);
    spe_hdf_file_version= hdf5read(file_name,data_field_names{5});
    spe_hdf_code_version= spe_hdf.spe_hdf_version;
end

if spe_hdf_file_version<1||spe_hdf_file_version>spe_hdf_code_version
     error('load_hdf_data:file_not_supported',[' can not recognise ',fext,' file version ',nxspe_version,' identified in file: ',filename]);
end
switch spe_hdf_file_version
    case (1)
        this=read_hdf5_v1(file_name,data_field_names);
    case (2)
        this=read_hdf5_v2(file_name,data_field_names);
    case(3)
        root = repmat( [root_nxspe_path,'/'],numel(data_field_names),1);
        root = cellstr(root)';
        data_field_names=strcat(root,data_field_names);
		data_attrib_names = spe_hdf_filestructure('data_attrib_names',ii);
        this=read_NXSPE_v1d1(file_name,data_field_names,data_attrib_names);
    otherwise
        error('SPE:load_hdf_Data',' no other spe_hdf vertion but 1, 2 and 3 are currently supported')        
end
%% -----------------------------------------------------------------
function rez=read_hdf5_v1(file_name,data_field_names)
rez.Ei  = NaN;
rez.en  = hdf5read(file_name,data_field_names{2});
rez.S   = hdf5read(file_name,data_field_names{3});
rez.ERR = hdf5read(file_name,data_field_names{4});

function rez=read_hdf5_v2(file_name,data_field_names)
rez.Ei  = hdf5read(file_name,data_field_names{1});
rez.en  = hdf5read(file_name,data_field_names{2});
rez.S   = hdf5read(file_name,data_field_names{3});
rez.ERR = hdf5read(file_name,data_field_names{4});

function rez = read_NXSPE_v1d1(file_name,data_field_names,attrib_names)
rez.Ei         = hdf5read(file_name,data_field_names{1});
rez.en         = hdf5read(file_name,data_field_names{2});

rez.S          = hdf5read(file_name,data_field_names{3});
rez.ERR     = hdf5read(file_name,data_field_names{4});

try
    rez.psi = hdf5read(file_name,data_field_names{6});
    
    EiUnits      = hdf5read(file_name,data_field_names{1},attrib_names{1});
    enUnits      = hdf5read(file_name,data_field_names{2},attrib_names{2});
    psiUnits     = hdf5read(file_name,data_field_names{6},attrib_names{6});
    rez.nxspe.EiUnits  =  EiUnits.Data;
    rez.nxspe.enUnits  = enUnits.Data;
    rez.nxspe.psiUnits = psiUnits.Data;
    rez.phx.azimuthal          = hdf5read(file_name,data_field_names{7});
    rez.phx.azimuthal_width = hdf5read(file_name,data_field_names{8});    
    rez.phx.polar              = hdf5read(file_name,data_field_names{9});
    rez.phx.polar_width        = hdf5read(file_name,data_field_names{10});    
    
catch
    warning('ReadNXSPE:format_error',['error reading addirional fields from nxspe file',lasterr()]);
end


