function [ok, mess, dout] = checkfields (d)
% Check fields for spe objects
%
%   >> [ok, mess] = checkfields (d)
%
%   ok      ok=true if valid, =false if not
%   mess    Message if not a valid object, empty string if is valid.

% Original author: T.G.Perring
%
%
% $Revision: 1757 $ ($Date: 2009-09-18 13:41:18 +0100 (Fri, 18 Sep 2009) $)
%   
% Initialise
% ------------
% Fields:
fields    = {'filename';'filepath';'S';'ERR';'en';'use_hdf';'Ei'};  % column
min_fields= {'filename';'filepath';'S';'ERR';'en'}; % minimal set of fields necessary;

ok=true;
mess = '';
dout = d;
existing_fields=fieldnames(dout);

if ~(sum(ismember(fields,existing_fields))==numel(existing_fields)) ||...
        ~(sum(ismember(existing_fields,min_fields))==numel(min_fields))
    ok=false; mess='fields inconsistent with spe object'; return
end

% Check contents of fields. Not exhaustive, but should eliminate common errors
% ------------------------------------------------------------------------------
if ~is_ok_row_string(dout.filename)
    ok=false; mess='Check filename string'; return
end
if ~is_ok_row_string(dout.filepath)
    ok=false; mess='Check filepath string'; return
end

ne=size(dout.S,1);
if ~isnumeric(dout.S)||~isnumeric(dout.ERR)||~isnumeric(dout.en)
    ok=false; mess='Signal,error and energy bin boundary arrays must be numeric'; return
end
if length(size(dout.S))~=2
    ok=false; mess='Signal array must be ne x ndet array (ne=no. energy bins, ndet=no. detectors)'; return
end
if ~isequal(size(dout.S),size(dout.ERR))
    ok=false; mess='Signal and error arrays do not match in size'; return
end
if ~isvector(dout.en)||numel(dout.en)~=ne+1
    ok=false; mess='Check number of energy bin boundaries'; return
end

% ensure energy boundaries form a column vector
dout.en=dout.en(:);


%==================================================================================================
function ok = is_ok_row_string(arg)
% Check if argument is a row character string, or an empty string
if (ischar(arg) && (isempty(arg)||length(size(arg))==2 && size(arg,1)==1))
    ok=true;
else
    ok=false;
end
