function [this,ok,mess]=get_spe(this,filename)
% Load ASCII .spe file or hdf (including nexus) spe file;
%   >> [this,ok,mess]=get_spe(this,filename)
%
% data has following fields:
%   data.filename   Name of file excluding path
%   data.filepath   Path to file including terminating file separator
%   data.S          [ne x ndet] array of signal values
%   data.ERR        [ne x ndet] array of error values (st. dev.)
%   data.en         Column vector of energy bin boundaries
%  
% if the file has 

% T.G.Perring   13/6/07
%
% DOES convert data <= -10^30 to NaN, contrary to mslice convention

ok=true;
mess='';

% Remove blanks from beginning and end of filename
file_tmp=strtrim(filename);

% Get file name and path (incl. final separator)
[filepath,filename,ext]=fileparts(file_tmp);
spe_hdf_file_ext=spe_hdf_filestructure('spe_hdf_file_ext');

binary_read_successfull    =false;   
existing_bin_exts              =ismember(spe_hdf_file_ext,ext);
%
if any(existing_bin_exts) || isempty(ext)
    try
        this=load_hdf_data(this,file_tmp);    
        this.filepath=filepath;        
        this.filename=filename;
        binary_read_successfull=true;        
    catch
        mess=['attemtp to load spe_hdf data, but error: ',lasterr()];
    end
end
% binary failed; let's try ASCII
if ~binary_read_successfull

    this.filepath=filepath;        
    this.filename=filename;

    file_tmp = fullfile(filepath,[filename,'.spe']);
    if ~exist(file_tmp,'file')
        file_tmp = fullfile(filepath,[filename,'.SPE']);
        if ~exist(file_tmp,'file')        
            mess = sprintf('SPE:get_spe: Can not find netigher binary nor ascii spe file: %s',file_tmp);
            ok=false;
            return;
        end
    end

    % Read ASCII spe file
    try
        [this.S,this.ERR,this.en]=libisisexc('IXTutility','getspe',file_tmp);
        this.en=this.en';
    catch       % try matlab algorithm
        try
            disp(['Matlab loading of .spe file : ' file_tmp]);
            [this.S,this.ERR,this.en]=get_spe_matlab(file_tmp);
        catch
            ok=false;
            mess=sprintf('Unable to read binary spe file and read ASCII spe file %s',file_tmp);
            return
        end
    end
end

ok=true;
% Put NaN for data <=10^30:
null_data = -1.0e30;    % conventional NaN in spe files
index=~isfinite(this.S)|this.S<=null_data|~isfinite(this.ERR);
if sum(index(:)>0)
    this.S(index)=NaN;
    this.ERR(index)=0;
end

[ne,ndet]=size(this.S);
disp(['Loaded spe data ( ' num2str(ndet) ' detector(s) and ' num2str(ne) ' energy bin(s)) from file : ']);
disp(file_tmp);

