function use_hdf=use_hdf(this,varargin)
% function checks and sets the parameter which defines if one has to use
% hdf5 format while reading/writing spe files 
% Usage:
%>>ans=use_hdf(spe_object)   -- queries if current settings request to use
%                               hdf instead ASCII format for reading/writing spe files
% ans = 
%       0                   -- forget hdf, use ASCII 
%       1                   -- use hdf when possible;
%       2                   -- use both
% 
% >>this=use_hdf(this,usage)   where usage is 0, 1, or 2
%  usage=0                     spe file has to be written in ASCII;
%  usage=1                     spe file has to be written in HDF5;
%  usage=2                     spe file has to be written in both formats;
%                            
% 
if isempty(varargin)
    use_hdf=get(homer_config,'use_hdf');
    switch use_hdf
        case 0; disp('use_hdf mode -- 0; ascii format is used for writing spe files'); return;
        case 1; disp('use_hdf mode -- 1; hdf   format is used for writing spe files'); return;           
        case 2; disp('use_hdf mode -- 2; both ASCII and hdf formats are used for writing spe files');                      
    end
    return
end

if varargin{1}<0 || varargin{1}>2 
    help spe.use_hdf;
    error('SPE:hdf_usage',' the argument has to be number ranging from 0 to 2');
end
use_hdf=this;
use_hdf.use_hdf=varargin{1};
set(homer_config,'use_hdf',use_hdf.use_hdf);

