function [ok,mess,ind,val]=parse_keywords(keywords,varargin)
% Simple verification that argument list has form:
%
%    key1, val1, key2, val2, ...
%
%  where keywords must be in the provided list
%
% Output:
%   ok      =true all ok, otherwise -false
%   mess    empty if ok, otherwise contains error message
%   ind     index of supplied keyword(s) into list of valid keywords
%   val     cell array of corresponding values (empty cell array if none found)


narg=numel(varargin);
if rem(narg,2)~=0
    ind=[]; val=[]; ok=false; mess='Check number of arguments'; return
end

i=1;
ind=zeros(1,narg/2);
val=cell(1,narg/2);
keyword_appeared=false(1,numel(keywords));

while i <= narg/2
    name = varargin{2*i-1};
    if ~ischar(name) || size(name,1)~=1
        ind=[]; val={}; ok=false; mess='Keywords must be must be character strings'; return
    end
    tmp=find(strcmpi(name,keywords));
    if numel(tmp)==1
        if ~keyword_appeared(tmp)
            ind(i)=tmp;
            val{i}=varargin{2*i};
            keyword_appeared(tmp)=true;
        else
            ind=[]; val={}; ok=false; mess='A keyword appears more than once - check input'; return
        end
    elseif isempty(tmp)
        ind=[]; val={}; ok=false; mess='Unrecognised keyword - check input'; return
    else
        ind=[]; val={}; ok=false; mess='List of keywords is in error - problem in calling program'; return
    end
    i=i+1;
end
ok=true;
mess='';
