function rmgpath(name,varargin)
% Remove one or more directories from a global path stored in the global path object
%
%   >> rmgpath(pathname,dir1,dir2,...)
% e.g. 
%   >> rmgpath('my_data_area','c:\rawfiles','d:\scratch\rawfiles')
%
% See also: mkgpath, delgpath, addgpath, rmgpath, addendgpath, addbeggpath, showgpath, existgpath


% Note: we check for unique occurences of directory names because the fortran code doesn't!

% Check global path name
if ~isvarname(name)
    error('Check global path is a character string')
end

if ~existgpath(name)
    error(['A global path with name ',name,' does not exist'])
end
    
% Check directory names are character strings
if isempty(varargin)
    return  % didn't ask for anything to be removed, so just return
end
for i=1:numel(varargin)
    [ok,dirs_rm]=str_make_cellstr(varargin{:});
    if ~ok
        error('Check that directory names are character strings or cellarrays of character strings')
    end
end

% Remove directories from path
dirs=getgpath(name);
[dirs_cmn,dirs_rm]=str_common(dirs_rm,dirs,'first');
if numel(dirs_cmn)~=numel(dirs_rm)
    display(['Not all directories to be removed exist in global path ',name,' - these ones will be ignored.'])
end
if ~isempty(dirs_cmn)
    r = libisisexc('IXTpath','deldir_varargin',IXTpath,name,dirs_cmn);
    ixf_global_var('fortran','set','GPATH',r);
else
    return  % none of the directories appeared in the global path, so do nothing
end
