function set_path(varargin)
% Set the directory where data is stored.
% 
%   >> set_path (path)                      % give full path
%   >> set_path (dir1, dir2, dir3, dir4)    % give components of path
%
% e.g.
%   >> set_path ('c:/maps_files/rawfiles')
%   >> set_path ('c:', 'maps_files', 'rawfiles')  % is equivalent to the first example
%   >> set_path ('inst_data:::')                  % if inst_data has been defined as a global search path


if nargin > 1
    for i=1:numel(varargin)
        if ~ischar(varargin{i})
            error('Check input argument(s) are character strings')
        end
    end
    dir_string = fullfile(varargin{:});   % This ensures that things are platform independent
else
    if nargin==0 || isempty(varargin{1})
        dir_string='';      % empty string allowed - it means that the path will be the current directory
    elseif ischar(varargin{1}) && size(varargin{1},1)==1
        dir_string = varargin{1};
    else
        error('Check input argument')
    end
end

% Need to check the terminal character still: if doesn't end in ::: or '/' or '\', add file separator
if ~isempty(dir_string)
    k=strfind(dir_string,':::');
    if (isempty(k) || k(end)~=length(dir_string)-2) && ~(dir_string(end:end)=='\' || dir_string(end:end)=='/')
        dir_string=[varargin{1},filesep];
    end
end

% Set global variable data_source field 'path'
ixf_global_var('data_source','set','path',dir_string);
