function write_nxs(object,filename,entry)
% Write Libisis object to NeXus file
%
%   >> write_nxs (object)               % prompt for file name
%   >> write_nxs (object, file_name)
%   >> write_nxs (object, file_name, entry_name)
%
%
%   object      Libisis object to be written
%
%   file_name   Name of NeXus file to be written
%
%   entry_name  Optionally give a particular entry to the top level directory
%              in the NeXus file.
%               The default entry name will be 'object' if object
%              is of class IXTobject
%                e.g. if class is IXTrunfile, the entry will be 'runfile'
%
% Example:
% ---------
%  Write a runfile object:
%   >> write_nxs(IXTrunfile, 'c:\my_data\ei50_psi90.nxs')
%
%
% NOTE: for reasons of backwards compatibility, the first two arguments can be reversed
%       i.e. write_nxs (file_name, object) is valid

% Modified T.G.Perring 3 Feb 2010

if nargin==0
    error('Check arguments')
end

% Prompt for file
if nargin==1
    if isobject(object)
        filename=putfile;
        if isempty(filename), error('No file given'), end
    else
        error('Invalid object input')
    end
end

% Check input object and file name
if nargin>=2
    if isobject(filename) && ischar(object)
        tmp=object; object=filename; filename=tmp;  % reverse (backwards compatibility with old call syntax
    elseif ~(ischar(filename) && isobject(object))
        error('Invalid filename or object input')
    end
    if isempty(filename) || size(filename,1)~=1
        error('Filename must be a character string')
    end
end

% Check entry name
if nargin==3
    if ~(ischar(entry) && (isempty(entry) || size(entry,1)==1))  % accept empty character
        error('Entry name must be a character string')
    end
end

% Write file
disp(['Creating file: ',filename]);
fio=open(IXTfileio,translate_write(filename),4);
if nargin==3
    write(object,fio,entry);
    fio=close(fio);
else
    write(object,fio,'');
    fio=close(fio);
end
